@@ -4,8 +4,6 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <config-kitinerary.h>
-
 #include "testhelpers.h"
 
 #include <KItinerary/ExtractorEngine>
@@ -61,7 +59,7 @@ private Q_SLOTS:
                 continue;
             }
 
-            QDirIterator it(baseDir.path(), {QStringLiteral("*.txt"), QStringLiteral("*.html"), QStringLiteral("*.pdf"), QStringLiteral("*.pkpass"), QStringLiteral("*.ics"), QStringLiteral("*.eml"), QStringLiteral("*.mbox"), QStringLiteral("*.bin"), QStringLiteral("*.png")}, QDir::Files | QDir::Readable | QDir::NoSymLinks, QDirIterator::Subdirectories);
+            QDirIterator it(baseDir.path(), {QStringLiteral("*.txt"), QStringLiteral("*.html"), QStringLiteral("*.pdf"), QStringLiteral("*.pkpass"), QStringLiteral("*.ics"), QStringLiteral("*.eml"), QStringLiteral("*.mbox"), QStringLiteral("*.bin"), QStringLiteral("*.png"), QStringLiteral("*.jpg")}, QDir::Files | QDir::Readable | QDir::NoSymLinks, QDirIterator::Subdirectories);
             while (it.hasNext()) {
                 it.next();
                 // ignore context files
@@ -83,7 +81,13 @@ private Q_SLOTS:
         QFETCH(QString, inputFile);
 
         m_engine.clear();
-        m_engine.setHints(inputFile.endsWith(QLatin1String(".png")) ? ExtractorEngine::ExtractFullPageRasterImages : ExtractorEngine::NoHint);
+        if (inputFile.endsWith(QLatin1String(".png")) || inputFile.endsWith(QLatin1String(".pdf")) || inputFile.endsWith(QLatin1String(".jpg"))) {
+            m_engine.setHints(ExtractorEngine::ExtractFullPageRasterImages);
+        } else if (inputFile.endsWith(QLatin1String(".ics"))) {
+            m_engine.setHints(ExtractorEngine::ExtractGenericIcalEvents);
+        } else {
+            m_engine.setHints(ExtractorEngine::NoHint);
+        }
 
         QFile inFile(inputFile);
         const auto openFlags = inputFile.endsWith(QLatin1String(".txt")) ? QFile::Text : QFile::ReadOnly;
@@ -112,12 +116,6 @@ private Q_SLOTS:
             QSKIP("nothing extracted");
             return;
         }
-#if !HAVE_ZXING
-        if (jsonResult.isEmpty()) {
-            QSKIP("nothing extracted, but ZXing is missing!");
-            return;
-        }
-#endif
         QVERIFY(!jsonResult.isEmpty());
         const auto result = JsonLdDocument::fromJson(jsonResult);
         ExtractorPostprocessor postproc;
