@@ -92,15 +92,14 @@ static bool isSameFlight(const Flight &lhs, const Flight &rhs);
 static bool isSameTrainTrip(const TrainTrip &lhs, const TrainTrip &rhs);
 static bool isSameBusTrip(const BusTrip &lhs, const BusTrip &rhs);
 static bool isSameBoatTrip(const BoatTrip &lhs, const BoatTrip &rhs);
-static bool isSameLodingBusiness(const LodgingBusiness &lhs, const LodgingBusiness &rhs);
-static bool isSameFoodEstablishment(const FoodEstablishment &lhs, const FoodEstablishment &rhs);
+static bool isSameLocalBusiness(const LocalBusiness &lhs, const LocalBusiness &rhs);
 static bool isSameTouristAttractionVisit(const TouristAttractionVisit &lhs, const TouristAttractionVisit &rhs);
 static bool isSameTouristAttraction(const TouristAttraction &lhs, const TouristAttraction &rhs);
 static bool isSameEvent(const Event &lhs, const Event &rhs);
 static bool isSameRentalCar(const RentalCar &lhs, const RentalCar &rhs);
 static bool isSameTaxiTrip(const Taxi &lhs, const Taxi &rhs);
 static bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes);
-static bool isMinimalCancelationFor(const QVariant &r, const Reservation &cancel);
+static bool isMinimalCancelationFor(const Reservation &res, const Reservation &cancel);
 static bool isSameTicketToken(const QVariant &lhs, const QVariant &rhs);
 
 bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes)
@@ -120,12 +119,25 @@ bool isSameReservation(const Reservation &lhsRes, const Reservation &rhsRes)
     return true;
 }
 
+bool isSubType(const QVariant &lhs, const QVariant &rhs)
+{
+    const auto lhsMt = QMetaType(lhs.userType());
+    const auto rhsMt = QMetaType(rhs.userType());
+    const auto lhsMo = lhsMt.metaObject();
+    const auto rhsMo = rhsMt.metaObject();
+    // for enums/flags, this is the enclosing meta object starting with Qt6!
+    if (!lhsMo || !rhsMo || (lhsMt.flags() & QMetaType::IsGadget) == 0  || (rhsMt.flags() & QMetaType::IsGadget) == 0) {
+        return false;
+    }
+    return lhsMo->inherits(rhsMo);
+}
+
 bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
 {
     if (lhs.isNull() || rhs.isNull()) {
         return false;
     }
-    if (lhs.userType() != rhs.userType()) {
+    if (!isSubType(lhs, rhs) && !isSubType(rhs, lhs)) {
         return false;
     }
 
@@ -150,7 +162,7 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
 
         // one side is a minimal cancellation, matches the reservation number and has a plausible modification time
         // in this case don't bother comparing content (which will fail), we accept this directly
-        if (isMinimalCancelationFor(lhs, rhsRes) || isMinimalCancelationFor(rhs, lhsRes)) {
+        if (isMinimalCancelationFor(lhsRes, rhsRes) || isMinimalCancelationFor(rhsRes, lhsRes)) {
             return true;
         }
     }
@@ -221,11 +233,6 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         const auto rhsRes = rhs.value<LodgingReservation>();
         return isSame(lhsRes.reservationFor(), rhsRes.reservationFor()) && lhsRes.checkinTime().date() == rhsRes.checkinTime().date();
     }
-    if (JsonLd::isA<LodgingBusiness>(lhs)) {
-        const auto lhsHotel = lhs.value<LodgingBusiness>();
-        const auto rhsHotel = rhs.value<LodgingBusiness>();
-        return isSameLodingBusiness(lhsHotel, rhsHotel);
-    }
 
     // Rental Car
     if (JsonLd::isA<RentalCarReservation>(lhs)) {
@@ -271,10 +278,12 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
 
         return isSame(lhsRes.reservationFor(), rhsRes.reservationFor()) && lhsRes.startTime().date() == endTime.date();
     }
-    if (JsonLd::isA<FoodEstablishment>(lhs)) {
-        const auto lhsRestaurant = lhs.value<FoodEstablishment>();
-        const auto rhsRestaurant = rhs.value<FoodEstablishment>();
-        return isSameFoodEstablishment(lhsRestaurant, rhsRestaurant);
+
+    // generic busniess (hotel, restaurant)
+    if (JsonLd::canConvert<LocalBusiness>(lhs)) {
+        const auto lhsBusiness = JsonLd::convert<LocalBusiness>(lhs);
+        const auto rhsBusiness = JsonLd::convert<LocalBusiness>(rhs);
+        return isSameLocalBusiness(lhsBusiness, rhsBusiness);
     }
 
     // event reservation
@@ -333,6 +342,10 @@ bool MergeUtil::isSame(const QVariant& lhs, const QVariant& rhs)
         }
     }
 
+    if (lhs.userType() != rhs.userType()) {
+        return false;
+    }
+
     // custom comparators
     const auto it = std::lower_bound(s_mergeCompareFuncs.begin(), s_mergeCompareFuncs.end(), lhs.userType());
     if (it != s_mergeCompareFuncs.end() && (*it).metaTypeId == lhs.userType()) {
@@ -472,18 +485,13 @@ static bool isSameBoatTrip(const BoatTrip& lhs, const BoatTrip& rhs)
         && LocationUtil::isSameLocation(lhs.arrivalBoatTerminal(), rhs.arrivalBoatTerminal());
 }
 
-static bool isSameLodingBusiness(const LodgingBusiness &lhs, const LodgingBusiness &rhs)
+static bool isSameLocalBusiness(const LocalBusiness &lhs, const LocalBusiness &rhs)
 {
     if (lhs.name().isEmpty() || rhs.name().isEmpty()) {
         return false;
     }
 
-    return lhs.name() == rhs.name();
-}
-
-static bool isSameFoodEstablishment(const FoodEstablishment &lhs, const FoodEstablishment &rhs)
-{
-    if (lhs.name().isEmpty() || rhs.name().isEmpty()) {
+    if (!LocationUtil::isSameLocation(lhs, rhs)) {
         return false;
     }
 
@@ -549,12 +557,23 @@ static bool isNameEqualish(const QString &lhs, const QString &rhs)
     return true;
 }
 
+static bool isPartialName(const Person &fullName, const Person &partialName)
+{
+    if (fullName.familyName().isEmpty() || fullName.givenName().isEmpty() || !partialName.givenName().isEmpty()) {
+        return false;
+    }
+    return isNameEqualish(fullName.familyName(), partialName.name());
+}
+
 bool MergeUtil::isSamePerson(const Person& lhs, const Person& rhs)
 {
     if (isNameEqualish(lhs.name(), rhs.name()) ||
         (isNameEqualish(lhs.givenName(), rhs.givenName()) && isNameEqualish(lhs.familyName(), rhs.familyName()))) {
         return true;
     }
+    if (isPartialName(lhs, rhs) || isPartialName(rhs, lhs)) {
+        return true;
+    }
 
     const auto lhsNameT = StringUtil::transliterate(lhs.name());
     const auto lhsGivenNameT = StringUtil::transliterate(lhs.givenName());
@@ -671,7 +690,7 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
     if (lhs.isNull()) {
         return rhs;
     }
-    if (lhs.userType() != rhs.userType()) {
+    if (!isSubType(lhs, rhs) && !isSubType(rhs, lhs)) {
         qCWarning(Log) << "type mismatch during merging:" << lhs << rhs;
         return {};
     }
@@ -686,6 +705,10 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
     }
 
     auto res = lhs;
+    if (lhs.userType() != rhs.userType() && isSubType(rhs, lhs)) {
+        res = rhs;
+    }
+
     const auto mo = QMetaType(res.userType()).metaObject();
     for (int i = 0; i < mo->propertyCount(); ++i) {
         const auto prop = mo->property(i);
@@ -722,10 +745,9 @@ QVariant MergeUtil::merge(const QVariant &lhs, const QVariant &rhs)
     return res;
 }
 
-bool isMinimalCancelationFor(const QVariant &r, const Reservation &cancel)
+bool isMinimalCancelationFor(const Reservation &res, const Reservation &cancel)
 {
-    const auto res = JsonLd::convert<Reservation>(r);
-    if (res.reservationStatus() == Reservation::ReservationCancelled || cancel.reservationStatus() != Reservation::ReservationCancelled) {
+    if (cancel.reservationStatus() != Reservation::ReservationCancelled) {
         return false;
     }
     if (!equalAndPresent(res.reservationNumber(), cancel.reservationNumber())) {
@@ -734,7 +756,7 @@ bool isMinimalCancelationFor(const QVariant &r, const Reservation &cancel)
     if (!cancel.modifiedTime().isValid() || !cancel.reservationFor().isNull()) {
         return false;
     }
-    return SortUtil::startDateTime(r) > cancel.modifiedTime();
+    return SortUtil::startDateTime(res) > cancel.modifiedTime();
 }
 
 bool isSameTicketToken(const QVariant &lhs, const QVariant &rhs)
