@@ -5,7 +5,7 @@
 */
 
 #include "qimagepurebinarizer.h"
-#if HAVE_ZXING && !ZXING_USE_READBARCODE
+#if !ZXING_USE_READBARCODE
 
 #include <ZXing/BitArray.h>
 
